forecast: Out-of-Sample Forecasting

View source: R/forecast.R

forecastR Documentation

Out-of-Sample Forecasting

Description

The generic function forecast computes forecasts from time series models.

Usage

forecast(object, ...)

Arguments

object

A model object.

...

Additional arguments passed to methods.

Value

Depends on the method dispatched. See forecast.rbfmvar for the RBFM-VAR method, which returns an object of class "rbfmvar_forecast".


rbfmvar documentation built on April 9, 2026, 9:08 a.m.